import { CssParser, CssProp, CssText, } from "./public-api";
export class CssStyleDeclaration {
    constructor() {
        this.styles = new Map();
        this.dynamicStyles = [];
        this.domCallbacks = [];
    }
    hasDomCallbacks() {
        return this.domCallbacks.length > 0;
    }
    hasDynamicStyles() {
        return this.dynamicStyles.length > 0;
    }
    isEmpty() {
        return this.styles.size === 0 &&
            this.dynamicStyles.length === 0 &&
            this.domCallbacks.length === 0;
    }
    callDomCallbacks(box, dom, flowRoot) {
        this.domCallbacks.forEach(callback => callback.call(box, dom, flowRoot));
    }
    getPropertyValue(prop) {
        return this.styles.get(prop) || null;
    }
    setProperty(prop, value) {
        const cssProp = new CssProp(prop);
        const cssText = new CssText({ prop: cssProp.value, value: value });
        const declrs = CssParser.parseDeclaration(cssProp, cssText);
        return declrs.reduce((acm, declr) => {
            acm.styles.set(declr.prop, declr.value);
            return acm;
        }, this);
    }
    addDynamicStyle(dynamicStyle) {
        this.dynamicStyles.push(dynamicStyle);
        return this;
    }
    addDomCallback(callback) {
        this.domCallbacks.push(callback);
        return this;
    }
    removeProperty(prop) {
        return this.styles.delete(prop);
    }
    forEach(fn) {
        this.styles.forEach((value, key) => fn(key, value));
    }
    mergeFrom(src) {
        src.styles.forEach((value, prop) => {
            this.styles.set(prop, value);
        });
        this.dynamicStyles = this.dynamicStyles.concat(src.dynamicStyles);
        this.domCallbacks = this.domCallbacks.concat(src.domCallbacks);
        return this;
    }
    getDynamicStyle(element, parentCtx) {
        return this.dynamicStyles.reduce((style, dynamic) => {
            const dynamicStyle = dynamic.call(element, parentCtx) || {};
            return style.mergeFrom(dynamicStyle);
        }, new CssStyleDeclaration());
    }
    acceptCssEvaluator(visitor) {
        return visitor.visitUnmanagedCssProps(this);
    }
}
//# sourceMappingURL=css-style-declaration.js.map