import { CssRule, CssStyleDeclaration, CssParser, } from "./public-api";
export class CssStyleSheet {
    constructor(cssRules) {
        this.rules = [];
        if (cssRules) {
            this.addCssRules(cssRules);
        }
    }
    sort() {
        this.rules.sort(CssRule.compare);
        return this;
    }
    mergeStyleSheet(stylesheet) {
        this.rules = this.rules.concat(stylesheet.rules);
        this.sort();
        return this;
    }
    getPseudoRules() {
        return this.rules.filter(rule => rule.peSelector !== null);
    }
    getStyleOfElement(element) {
        const rules = this.rules.filter(rule => rule.test(element));
        return rules.reduce((block, rule) => {
            return block.mergeFrom(rule.style);
        }, new CssStyleDeclaration());
    }
    addCssRules(rules) {
        for (let selector in rules) {
            let addedRules = CssParser.parseRule(selector, rules[selector]);
            this.rules = this.rules.concat(addedRules);
        }
        return this.sort();
    }
    addRule(selector, declrBlock) {
        const addedRules = CssParser.parseRule(selector, declrBlock);
        this.rules = this.rules.concat(addedRules);
        return this.sort();
    }
}
//# sourceMappingURL=css-stylesheet.js.map