export class LayoutSection {
    constructor(header) {
        this.header = header;
        this.children = [];
        this.closed = false;
        this.pageIndex = 0;
    }
    isRoot() {
        return !!!this.parent;
    }
    isNode() {
        return this.children.length > 0;
    }
    isLeaf() {
        return this.children.length === 0;
    }
    setHeader(header) {
        if (!this.header) {
            this.header = header;
        }
    }
    addChild(child) {
        this.children.push(child);
        child.parent = this;
        return this;
    }
    get level() {
        return this.header ? LayoutSection.getHeaderLevel(this.header) : -1;
    }
    get title() {
        if (this.header) {
            return this.header.textContent;
        }
        return (!this.parent) ? "(root)" : "no title";
    }
    getClosestSectionByPageIndex(pageIndex, last) {
        if (this.pageIndex >= pageIndex) {
            return this;
        }
        let prev = this;
        for (let i = 0; i < this.children.length; i++) {
            const child = this.children[i];
            const section = child.getClosestSectionByPageIndex(pageIndex, prev);
            if (section.pageIndex === pageIndex) {
                return section;
            }
            if (section.pageIndex > pageIndex) {
                return prev;
            }
            prev = section;
        }
        return prev;
    }
    static isHeaderElement(element) {
        switch (element.tagName) {
            case "h1":
            case "h2":
            case "h3":
            case "h4":
            case "h5":
            case "h6":
                return true;
        }
        return false;
    }
    static getHeaderLevel(element) {
        switch (element.tagName) {
            case "h1": return 1;
            case "h2": return 2;
            case "h3": return 3;
            case "h4": return 4;
            case "h5": return 5;
            case "h6": return 6;
        }
        throw new Error(`Invalid header:${element.tagName}`);
    }
    static isSectioningElement(element) {
        switch (element.tagName) {
            case "body":
            case "section":
            case "nav":
            case "article":
            case "aside":
                return true;
        }
        return false;
    }
    static isSectioningRootElement(element) {
        switch (element.tagName) {
            case "body":
            case "blockquote":
            case "fieldset":
            case "figure":
            case "td":
                return true;
        }
        return false;
    }
}
//# sourceMappingURL=layout-section.js.map