import { LogicalEdgeSize, LogicalEdgeDirections, CssText, } from "./public-api";
export class LogicalMargin extends LogicalEdgeSize {
    static parseShorthand(css_text) {
        let vs = CssText.getValue4D(css_text.value);
        return [
            { prop: "margin-before", value: vs[0] },
            { prop: "margin-end", value: vs[1] },
            { prop: "margin-after", value: vs[2] },
            { prop: "margin-start", value: vs[3] }
        ];
    }
    static load(element) {
        return new LogicalMargin(LogicalEdgeDirections.reduce((size, direction) => {
            size[direction] = LogicalEdgeSize.loadDirection(element, `margin-${direction}`);
            return size;
        }, {}));
    }
    static get none() {
        return new LogicalMargin(LogicalEdgeSize.zeroValue);
    }
    clone() {
        return new LogicalMargin(this.values);
    }
    getPropByLogicalDirection(direction) {
        return `margin-${direction}`;
    }
    acceptCssEvaluator(visitor) {
        return visitor.visitLogicalMargin(this);
    }
}
//# sourceMappingURL=logical-margin.js.map