import { Config, LayoutResult, LogicalSize, PhysicalSize, ReReducer, ReShrinkResizer, } from './public-api';
export class ReNodeGenerator {
    constructor(context, reducer = ReReducer.instance, resizer = ReShrinkResizer.instance) {
        this.context = context;
        this.reducer = reducer;
        this.resizer = resizer;
        this.generator = this.createGenerator();
    }
    getNext() {
        const next = this.generator.next();
        return next.done ? undefined : next.value;
    }
    *createGenerator() {
        if (Config.debugLayout) {
            console.group(`${this.context.name}`);
        }
        const writingMode = this.context.env.writingMode;
        const maxSize = new LogicalSize({
            measure: this.context.maxMeasure - this.context.env.edge.measure,
            extent: this.context.maxExtent - this.context.env.edge.extent
        });
        let physicalSize = PhysicalSize.load(this.context.env.element);
        let logicalSize = physicalSize.getLogicalSize(writingMode);
        if (logicalSize.extent > maxSize.extent || logicalSize.measure > maxSize.measure) {
            logicalSize = this.resizer.resize(this.context, logicalSize, maxSize);
            physicalSize = logicalSize.getPhysicalSize(writingMode);
        }
        if (this.context.restExtent < logicalSize.extent) {
            yield LayoutResult.pageBreak(this.context, "re extent is not enough for restExtent");
        }
        if (this.context.env.display.isInlineLevel() && this.context.restMeasure < logicalSize.measure) {
            yield LayoutResult.lineBreak(this.context, "restMeasure is not enough for inline re");
        }
        if (this.context.restExtent < logicalSize.extent) {
            yield LayoutResult.pageBreak(this.context, "re extent is not enough for restExtent");
        }
        const curRestMeasure = this.context.restMeasure;
        yield this.context.acceptLayoutReducer(this.reducer, logicalSize, physicalSize);
        if (this.context.env.display.isInlineLevel() && curRestMeasure === logicalSize.measure) {
            yield LayoutResult.lineBreak(this.context, "restMeasure is just filled by measure of re(inline)");
        }
        if (Config.debugLayout) {
            console.groupEnd();
        }
    }
}
//# sourceMappingURL=re-node-generator.js.map