import { LogicalCursorPos, FlowFormatContext, } from './public-api';
export class RubyChildFormatContext extends FlowFormatContext {
    get restMeasure() {
        return Infinity;
    }
    get restExtent() {
        return Infinity;
    }
}
export class RubyFormatContext {
    constructor(env, parent) {
        this.env = env;
        this.parent = parent;
        this.cursorPos = LogicalCursorPos.zero;
        this.rubyGroups = [];
        this.progress = 1;
    }
    acceptLayoutReducer(visitor, rubyGroup) {
        return visitor.visit(this, rubyGroup);
    }
    get boxPos() {
        return {
            offsetPos: this.parent.flowRootPos,
            clientPos: { start: 0, before: 0 }
        };
    }
    get globalPos() {
        return this.parent.globalPos.translate(this.cursorPos);
    }
    get flowRootPos() {
        return this.parent.flowRootPos.translate(this.cursorPos);
    }
    get localPos() {
        return this.parent.localPos.translate(this.cursorPos);
    }
    get lineHeadPos() {
        return this.parent.lineHeadPos;
    }
    get pageRoot() {
        return this.parent.pageRoot;
    }
    get flowRoot() {
        return this.parent.flowRoot;
    }
    get inlineRoot() {
        return this.parent.inlineRoot;
    }
    get contextRestMeasure() {
        return this.parent.contextRestMeasure;
    }
    get restMeasure() {
        return this.parent.contextRestMeasure - this.cursorPos.start;
    }
    get restExtent() {
        return this.parent.restExtent - this.cursorPos.before;
    }
    get maxMeasure() {
        return this.parent.maxMeasure;
    }
    get maxExtent() {
        return this.parent.maxExtent;
    }
    get rootMeasure() {
        return this.parent.rootMeasure;
    }
    get rootExtent() {
        return this.parent.rootExtent;
    }
    addRubyBase(rb) {
        this.rb = rb;
        this.groupRuby();
    }
    addRubyText(rt) {
        this.rt = rt;
        this.groupRuby();
    }
    groupRuby() {
        if (!this.rb || !this.rt) {
            return;
        }
        this.rubyGroups.push({ rb: this.rb, rt: this.rt });
        this.rb = this.rt = undefined;
    }
}
//# sourceMappingURL=ruby-format-context.js.map