import { Config } from './public-api';
export var Utils;
(function (Utils) {
    Utils.atoi = (x, failOver = 0) => {
        const n = parseInt(x, 10);
        if (isNaN(n)) {
            if (Config.debugLayout) {
                console.warn(`${x} is not a number, so use ${failOver}`);
            }
            return failOver;
        }
        return n;
    };
    Utils.isNumber = (x) => {
        return isNaN(Number(x)) === false;
    };
    Utils.mergeDefault = (obj, defaults) => {
        return Object.assign(Object.assign({}, defaults), obj);
    };
    class Enum {
        static fromArray(o) {
            return o.reduce((res, key) => {
                res[key] = key;
                return res;
            }, Object.create(null));
        }
        static toObjArray(enum_obj) {
            return Object.keys(enum_obj).map(key => {
                return {
                    id: enum_obj[key],
                    name: key
                };
            });
        }
        static toValueArray(enum_obj) {
            return Object.keys(enum_obj).map(key => {
                return enum_obj[key];
            });
        }
        static member(enum_obj, value) {
            let array = Enum.toValueArray(enum_obj);
            return array.indexOf(value) >= 0;
        }
    }
    Utils.Enum = Enum;
    class Choice {
        static select(args) {
            if (args.values.indexOf(args.value) >= 0) {
                return args.value;
            }
            return args.initial;
        }
    }
    Utils.Choice = Choice;
    class String {
        static getUnicodeProp(str) {
            let code = str.charCodeAt(0);
            let hex = code.toString(16).toUpperCase();
            switch (hex.length) {
                case 0: return "U+0000";
                case 1: return "U+000" + hex;
                case 2: return "U+00" + hex;
                case 3: return "U+0" + hex;
            }
            return "U+" + hex;
        }
        static multiSpaceToSingle(str) {
            return str.replace(/\s+/g, " ");
        }
        static multiSpaceToSingle2(str) {
            return str.replace(/[\u0020\f\n\r\t\v\u00A0\u1680\u180e\u2000-\u200A\u2028\u2029\u202F\u205F\uFEFF]+/gm, " ");
        }
        static capitalize(str) {
            if (str === "") {
                return "";
            }
            return str.charAt(0).toUpperCase() + str.slice(1);
        }
        static camelToChain(name) {
            return name.replace(/[A-Z]/g, (s) => {
                return "-" + s.toLowerCase();
            });
        }
        static chainToCamel(name) {
            return (name.indexOf("-") < 0) ? name : name.split("-").map((part, i) => {
                return (i === 0) ? part : this.capitalize(part);
            }).join("");
        }
    }
    Utils.String = String;
})(Utils || (Utils = {}));
//# sourceMappingURL=utils.js.map